import { ApiProperty, IntersectionType, PartialType } from '@nestjs/swagger';
import {
  IsArray,
  IsDate,
  IsDateString,
  IsEnum,
  IsIn,
  IsInt,
  IsNumber,
  IsOptional,
  IsString,
  Matches,
  MinLength
} from 'class-validator';
import { PagerDto } from '~/common/dto/pager.dto';
import { Storage } from '../tools/storage/storage.entity';
import { ContractStatusEnum } from '~/constants/enum';

export class ContractDto {
  @ApiProperty({ description: '合同编号' })
  @Matches(/^[a-z0-9A-Z]+$/, { message: '合同编号只能包含字母和数字' })
  @IsString()
  contractNumber: string;

  @ApiProperty({ description: '合同标题' })
  @IsString()
  title: string;

  @ApiProperty({ description: '合同类型' })
  @IsNumber()
  type: number;

  @ApiProperty({ description: '甲方' })
  @IsString()
  partyA: string;

  @ApiProperty({ description: '乙方' })
  @IsString()
  partyB: string;

  @ApiProperty({ description: '签订日期' })
  @IsOptional()
  @IsDateString()
  signingDate?: string;

  @ApiProperty({ description: '交付期限' })
  @IsOptional()
  @IsDateString()
  deliveryDeadline?: string;

  @ApiProperty({ description: '审核状态(字典)' })
  @IsOptional()
  @IsEnum(ContractStatusEnum)
  status: number;

  @ApiProperty({ description: '附件' })
  files: Storage[];
}

export class ContractUpdateDto extends PartialType(ContractDto) {
  @ApiProperty({ description: '附件' })
  @IsOptional()
  @IsArray()
  fileIds: number[];
}
export class ContractQueryDto extends IntersectionType(
  PagerDto<ContractDto>,
  PartialType(ContractDto)
) {}
