import { ApiHideProperty, ApiProperty } from '@nestjs/swagger';
import { InjectRepository } from '@nestjs/typeorm';
import { Expose } from 'class-transformer';
import pinyin from 'pinyin';
import {
  BeforeInsert,
  Column,
  Entity,
  JoinColumn,
  JoinTable,
  ManyToMany,
  ManyToOne,
  Relation,
  Repository
} from 'typeorm';
import { CommonEntity } from '~/common/entity/common.entity';
import { MaterialsInOrOutEnum, ParamConfigEnum } from '~/constants/enum';
import { ProductEntity } from '~/modules/product/product.entity';
import { ProjectEntity } from '~/modules/project/project.entity';
import { ParamConfigEntity } from '~/modules/system/param-config/param-config.entity';
import { Storage } from '~/modules/tools/storage/storage.entity';
import { MaterialsInventoryEntity } from '../materials_inventory.entity';
@Entity({ name: 'materials_in_out' })
export class MaterialsInOutEntity extends CommonEntity {
  @Column({
    name: 'inventory_inout_number',
    type: 'varchar',
    length: 50,
    comment: '原材料出入库编号'
  })
  @ApiProperty({ description: '原材料出入库编号' })
  inventoryInOutNumber: string;

  @Column({
    name: 'product_id',
    type: 'int',
    comment: '产品'
  })
  @ApiProperty({ description: '产品' })
  productId: number;

  @Column({
    name: 'inventory_id',
    type: 'int',
    comment: '库存'
  })
  @ApiProperty({ description: '库存' })
  inventoryId: number;

  @Column({
    name: 'in_or_out',
    type: 'tinyint',
    comment: '入库或出库'
  })
  @ApiProperty({ description: '入库或出库 0:入库 1:出库' })
  inOrOut: MaterialsInOrOutEnum;

  @Column({
    name: 'time',
    type: 'date',
    nullable: true,
    comment: '时间'
  })
  @ApiProperty({ description: '时间' })
  time: Date;

  @Column({
    name: 'quantity',
    type: 'int',
    default: 0,
    comment: '数量'
  })
  @ApiProperty({ description: '数量' })
  quantity: number;

  @Column({
    name: 'unit_price',
    type: 'decimal',
    precision: 15,
    default: 0,
    scale: 10,
    comment: '单价'
  })
  @ApiProperty({ description: '单价' })
  unitPrice: number;

  @Column({
    name: 'amount',
    type: 'decimal',
    precision: 15,
    default: 0,
    scale: 10,
    comment: '金额'
  })
  @ApiProperty({ description: '金额' })
  amount: number;

  @Column({ name: 'agent', type: 'varchar', length: 50, comment: '经办人', nullable: true })
  @ApiProperty({ description: '经办人' })
  agent: string;

  @Column({
    name: 'issuance_number',
    type: 'varchar',
    length: 100,
    nullable: true,
    comment: '领料单号'
  })
  @ApiProperty({ description: '领料单号' })
  issuanceNumber: string;

  @Column({ name: 'remark', type: 'varchar', length: 255, comment: '备注', nullable: true })
  @ApiProperty({ description: '备注' })
  remark: string;

  @Column({ name: 'project_id', type: 'int', comment: '项目', nullable: true })
  @ApiProperty({ description: '项目Id' })
  projectId: number;

  @Column({ name: 'is_delete', type: 'tinyint', default: 0, comment: '是否删除' })
  @ApiProperty({ description: '删除状态：0未删除，1已删除' })
  isDelete: number;

  @ManyToOne(() => ProjectEntity)
  @JoinColumn({ name: 'project_id' })
  project: ProjectEntity;

  @ManyToOne(() => ProductEntity)
  @JoinColumn({ name: 'product_id' })
  product: ProductEntity;

  @ManyToMany(() => Storage, storage => storage.materialsInOuts)
  @JoinTable({
    name: 'materials_in_out_storage',
    joinColumn: { name: 'materials_in_out_id', referencedColumnName: 'id' },
    inverseJoinColumn: { name: 'file_id', referencedColumnName: 'id' }
  })
  files: Relation<Storage[]>;

  @ManyToOne(() => MaterialsInventoryEntity)
  @JoinColumn({ name: 'inventory_id' })
  inventory: MaterialsInventoryEntity;
}
