import { ApiHideProperty, ApiProperty } from '@nestjs/swagger';
import { Column, Entity, JoinTable, ManyToMany, OneToMany, Relation } from 'typeorm';
import { CommonEntity } from '~/common/entity/common.entity';
import { Storage } from '../tools/storage/storage.entity';
import { ProductEntity } from '../product/product.entity';
import { MaterialsInOutEntity } from '../materials_inventory/in_out/materials_in_out.entity';

/**
 * 项目实体类
 */
@Entity({ name: 'project' })
export class ProjectEntity extends CommonEntity {
  @Column({
    name: 'name',
    type: 'varchar',
    unique: true,
    length: 255,
    comment: '项目名称'
  })
  @ApiProperty({ description: '项目名称' })
  name: string;

  @Column({ name: 'is_delete', type: 'tinyint', default: 0, comment: '是否删除' })
  @ApiProperty({ description: '删除状态：0未删除，1已删除' })
  isDelete: number;

  @ApiHideProperty()
  @OneToMany(() => MaterialsInOutEntity, product => product.project)
  materialsInOuts: Relation<MaterialsInOutEntity[]>;

  @ManyToMany(() => Storage, storage => storage.projects)
  @JoinTable({
    name: 'project_storage',
    joinColumn: { name: 'project_id', referencedColumnName: 'id' },
    inverseJoinColumn: { name: 'file_id', referencedColumnName: 'id' }
  })
  files: Relation<Storage[]>;
}
