import { ApiProperty } from '@nestjs/swagger';
import { Transform } from 'class-transformer';
import { IsArray, IsOptional, IsString } from 'class-validator';

import { PagerDto } from '~/common/dto/pager.dto';
import { formatToDate } from '~/utils';

export class LoginLogQueryDto extends PagerDto {
  @ApiProperty({ description: '用户名' })
  @IsString()
  @IsOptional()
  username: string;

  @ApiProperty({ description: '登录IP' })
  @IsOptional()
  @IsString()
  ip?: string;

  @ApiProperty({ description: '登录地点' })
  @IsOptional()
  @IsString()
  address?: string;

  @ApiProperty({ description: '登录时间' })
  @IsOptional()
  @IsArray()
  @Transform(params => {
    // 开始和结束时间用的是一天的开始和一天的结束的时分秒
    const [start, end] = params.value;
    return [start ? `${formatToDate(start)} 00:00:00` : null, end ? `${formatToDate(end)} 23:59:59` : null];
  })
  time?: string[];
}

export class TaskLogQueryDto extends PagerDto {
  @ApiProperty({ description: '用户名' })
  @IsOptional()
  @IsString()
  username: string;

  @ApiProperty({ description: '登录IP' })
  @IsString()
  @IsOptional()
  ip?: string;

  @ApiProperty({ description: '登录时间' })
  @IsOptional()
  time?: string[];
}

export class CaptchaLogQueryDto extends PagerDto {
  @ApiProperty({ description: '用户名' })
  @IsOptional()
  @IsString()
  username: string;

  @ApiProperty({ description: '验证码' })
  @IsString()
  @IsOptional()
  code?: string;

  @ApiProperty({ description: '发送时间' })
  @IsOptional()
  time?: string[];
}
