import { BadRequestException, Body, Controller, Post, Req, UseInterceptors } from '@nestjs/common';
import { ApiBody, ApiConsumes, ApiOperation, ApiTags } from '@nestjs/swagger';
import { FastifyRequest } from 'fastify';

import { ApiSecurityAuth } from '~/common/decorators/swagger.decorator';
import { AuthUser } from '~/modules/auth/decorators/auth-user.decorator';

import { Perm, definePermission } from '~/modules/auth/decorators/permission.decorator';

import { FileUploadDto } from './upload.dto';
import { UploadService } from './upload.service';

export const permissions = definePermission('upload', {
  UPLOAD: 'upload'
} as const);

@ApiSecurityAuth()
@ApiTags('Tools - 上传模块')
@Controller('upload')
export class UploadController {
  constructor(private uploadService: UploadService) {}

  @Post()
  @Perm(permissions.UPLOAD)
  @ApiOperation({ summary: '上传' })
  @ApiConsumes('multipart/form-data')
  @ApiBody({
    type: FileUploadDto
  })
  async upload(@Req() req: FastifyRequest, @AuthUser() user: IAuthUser, @Body() body: any) {
    if (!req.isMultipart()) throw new BadRequestException('Request is not multipart');
    const { file } = body;
    const bussinessModule = body.bussinessModule?.value;
    const bussinessRecordId = Number(body.bussinessRecordId?.value) || null;
    try {
      const savedFile = await this.uploadService.saveFile(
        file,
        user.uid,
        bussinessModule,
        bussinessRecordId
      );

      return {
        filename: savedFile
      };
    } catch (error) {
      console.log(error);
      throw new BadRequestException('上传失败');
    }
  }
}
